==> dojo_1.15.4+dfsg1.orig.tar.xz: dojo-release-1.15.4-src/dojo/cldr/nls/he/hebrew.js <==
define(
//begin v1.x content
{
	"field-tue-relative+-1": "יום שלישי שעבר",
	"field-year": "שנה",
	"dateFormatItem-Hm": "H:mm",
	"field-wed-relative+0": "יום רביעי",
	"field-wed-relative+1": "יום רביעי הבא",
	"timeFormat-short": "H:mm",
	"field-minute": "דקה",
	"field-tue-narrow-relative+0": "יום ג׳",
	"field-tue-narrow-relative+1": "יום ג׳ הבא",
	"field-thu-short-relative+0": "יום ה׳",
	"dateTimeFormat-short": "{1}, {0}",
	"field-thu-short-relative+1": "יום ה׳ הבא",
	"field-day-relative+0": "היום",
	"field-day-relative+1": "מחר",
	"field-day-relative+2": "מחרתיים",
	"field-wed-narrow-relative+-1": "יום ד׳ שעבר",
	"field-year-narrow": "שנ׳",
	"field-tue-relative+0": "יום שלישי",
	"field-tue-relative+1": "יום שלישי הבא",
	"field-second-short": "שנ׳",
	"dateFormatItem-MMMd": "d בMMMM",
	"dayPeriods-format-abbr-am": "לפנה״צ",
	"field-week-relative+0": "השבוע",
	"field-month-relative+0": "החודש",
	"field-week-relative+1": "השבוע הבא",
	"field-month-relative+1": "החודש הבא",
	"field-sun-narrow-relative+0": "יום א׳",
	"timeFormat-medium": "H:mm:ss",
	"field-mon-short-relative+0": "יום ב׳",
	"field-sun-narrow-relative+1": "יום א׳ הבא",
	"field-mon-short-relative+1": "יום ב׳ הבא",
	"field-second-relative+0": "עכשיו",
	"months-standAlone-narrow": [
		"תש׳",
		"חש׳",
		"כס׳",
		"טב׳",
		"שב׳",
		"א״א",
		"אד׳",
		"ני׳",
		"אי׳",
		"סי׳",
		"תמ׳",
		"אב",
		"אל׳"
	],
	"eraNames": [
		"לבה״ע"
	],
	"field-month-short": "חו׳",
	"dateFormatItem-GyMMMEd": "E, d בMMMM y G",
	"dateFormatItem-yyyyMd": "d בMMMM y",
	"field-day": "יום",
	"field-year-relative+-1": "השנה שעברה",
	"dayPeriods-format-wide-am": "לפנה״צ",
	"field-sat-short-relative+-1": "שבת שעברה",
	"field-hour-relative+0": "בשעה זו",
	"dateFormatItem-yyyyMEd": "E, d בMMMM y",
	"field-wed-relative+-1": "יום רביעי שעבר",
	"dateTimeFormat-medium": "{1}, {0}",
	"field-sat-narrow-relative+-1": "שבת שעברה",
	"field-second": "שנייה",
	"days-standAlone-narrow": [
		"א׳",
		"ב׳",
		"ג׳",
		"ד׳",
		"ה׳",
		"ו׳",
		"ש׳"
	],
	"dateFormat-long": "d בMMMM y",
	"dateFormatItem-GyMMMd": "d בMMMM y G",
	"field-quarter": "רבעון",
	"field-week-short": "שב׳",
	"quarters-standAlone-wide": [
		"רבעון 1",
		"רבעון 2",
		"רבעון 3",
		"רבעון 4"
	],
	"days-format-narrow": [
		"א׳",
		"ב׳",
		"ג׳",
		"ד׳",
		"ה׳",
		"ו׳",
		"ש׳"
	],
	"field-tue-short-relative+0": "יום ג׳",
	"field-tue-short-relative+1": "יום ג׳ הבא",
	"field-mon-relative+-1": "יום שני שעבר",
	"dateFormatItem-GyMMM": "MMMM y G",
	"field-month": "חודש",
	"field-day-narrow": "יום",
	"dateFormatItem-MMM": "MMMM",
	"field-minute-short": "דק׳",
	"field-dayperiod": "לפנה״צ/אחה״צ",
	"field-sat-short-relative+0": "שבת",
	"field-sat-short-relative+1": "שבת הבאה",
	"dateFormat-medium": "d בMMMM y",
	"dateFormatItem-yyyyMMMM": "MMMM y",
	"eraAbbr": [
		"לבה״ע"
	],
	"dayPeriods-format-abbr-pm": "אחה״צ",
	"dateFormatItem-yyyyM": "MMMM y",
	"field-second-narrow": "שנ׳",
	"field-mon-relative+0": "יום שני",
	"field-mon-relative+1": "יום שני הבא",
	"field-year-short": "שנ׳",
	"months-format-narrow": [
		"תש׳",
		"חש׳",
		"כס׳",
		"טב׳",
		"שב׳",
		"א״א",
		"אד׳",
		"ני׳",
		"אי׳",
		"סי׳",
		"תמ׳",
		"אב",
		"אל׳"
	],
	"field-quarter-relative+-1": "הרבעון הקודם",
	"dateFormatItem-yyyyMMMd": "d בMMMM y",
	"days-format-short": [
		"א׳",
		"ב׳",
		"ג׳",
		"ד׳",
		"ה׳",
		"ו׳",
		"ש׳"
	],
	"dayPeriods-format-wide-pm": "אחה״צ",
	"field-sat-relative+-1": "יום שבת שעבר",
	"dateTimeFormat-long": "{1} בשעה {0}",
	"dateFormatItem-Md": "d בMMMM",
	"field-hour": "שעה",
	"months-format-wide": [
		"תשרי",
		"חשוון",
		"כסלו",
		"טבת",
		"שבט",
		"אדר א׳",
		"אדר",
		"ניסן",
		"אייר",
		"סיוון",
		"תמוז",
		"אב",
		"אלול"
	],
	"dateFormat-full": "EEEE, d בMMMM y",
	"field-month-relative+-1": "החודש שעבר",
	"dateFormatItem-Hms": "H:mm:ss",
	"field-quarter-short": "רבע׳",
	"field-sat-narrow-relative+0": "שבת",
	"field-fri-relative+0": "יום שישי",
	"field-sat-narrow-relative+1": "שבת הבאה",
	"field-fri-relative+1": "יום שישי הבא",
	"field-sun-short-relative+0": "יום א׳",
	"field-sun-short-relative+1": "יום א׳ הבא",
	"field-week-relative+-1": "השבוע שעבר",
	"months-format-abbr": [
		"תשרי",
		"חשון",
		"כסלו",
		"טבת",
		"שבט",
		"אדר א׳",
		"אדר",
		"ניסן",
		"אייר",
		"סיון",
		"תמוז",
		"אב",
		"אלול"
	],
	"field-quarter-relative+0": "רבעון זה",
	"field-minute-relative+0": "בדקה זו",
	"timeFormat-long": "H:mm:ss z",
	"field-quarter-relative+1": "הרבעון הבא",
	"field-wed-short-relative+-1": "יום ד׳ שעבר",
	"dateFormat-short": "d בMMMM y",
	"field-thu-short-relative+-1": "יום ה׳ שעבר",
	"days-standAlone-wide": [
		"יום ראשון",
		"יום שני",
		"יום שלישי",
		"יום רביעי",
		"יום חמישי",
		"יום שישי",
		"יום שבת"
	],
	"dateFormatItem-yyyyMMMEd": "E, d בMMMM y",
	"field-mon-narrow-relative+-1": "יום ב׳ שעבר",
	"dateFormatItem-MMMMd": "d בMMMM",
	"field-thu-narrow-relative+-1": "יום ה׳ שעבר",
	"field-tue-narrow-relative+-1": "יום ג׳ שעבר",
	"dateFormatItem-H": "H",
	"dateFormatItem-yyyy": "y G",
	"field-wed-short-relative+0": "יום ד׳",
	"dateFormatItem-M": "MMMM",
	"months-standAlone-wide": [
		"תשרי",
		"חשוון",
		"כסלו",
		"טבת",
		"שבט",
		"אדר א׳",
		"אדר",
		"ניסן",
		"אייר",
		"סיוון",
		"תמוז",
		"אב",
		"אלול"
	],
	"field-wed-short-relative+1": "יום ד׳ הבא",
	"field-sun-relative+-1": "ביום ראשון שעבר",
	"dateFormatItem-MMMMEd": "E, d בMMMM",
	"days-standAlone-abbr": [
		"יום א׳",
		"יום ב׳",
		"יום ג׳",
		"יום ד׳",
		"יום ה׳",
		"יום ו׳",
		"שבת"
	],
	"dateTimeFormat-full": "{1} בשעה {0}",
	"months-format-abbr-leap": "אדר ב׳",
	"field-weekday": "יום בשבוע",
	"months-standAlone-narrow-leap": "א״ב",
	"field-sat-relative+0": "יום שבת",
	"field-sat-relative+1": "יום שבת הבא",
	"months-standAlone-abbr": [
		"תשרי",
		"חשון",
		"כסלו",
		"טבת",
		"שבט",
		"אדר א׳",
		"אדר",
		"ניסן",
		"אייר",
		"סיון",
		"תמוז",
		"אב",
		"אלול"
	],
	"months-format-wide-leap": "אדר ב׳",
	"months-format-narrow-leap": "א״ב",
	"timeFormat-full": "H:mm:ss zzzz",
	"dateFormatItem-MEd": "E, d בMMMM",
	"dateFormatItem-y": "y G",
	"field-thu-narrow-relative+0": "יום ה׳",
	"field-thu-narrow-relative+1": "יום ה׳ הבא",
	"field-sun-narrow-relative+-1": "יום א׳ שעבר",
	"field-mon-short-relative+-1": "יום ב׳ שעבר",
	"field-thu-relative+0": "יום חמישי",
	"field-thu-relative+1": "יום חמישי הבא",
	"field-fri-short-relative+-1": "יום ו׳ שעבר",
	"field-thu-relative+-1": "יום חמישי שעבר",
	"field-week": "שבוע",
	"quarters-format-wide": [
		"רבעון 1",
		"רבעון 2",
		"רבעון 3",
		"רבעון 4"
	],
	"dateFormatItem-Ed": "E ה-d",
	"field-wed-narrow-relative+0": "יום ד׳",
	"field-wed-narrow-relative+1": "יום ד׳ הבא",
	"dateFormatItem-yyyyMMM": "MMMM y",
	"field-fri-short-relative+0": "יום ו׳",
	"field-fri-short-relative+1": "ביום ו׳ הבא",
	"days-standAlone-short": [
		"א׳",
		"ב׳",
		"ג׳",
		"ד׳",
		"ה׳",
		"ו׳",
		"ש׳"
	],
	"months-standAlone-abbr-leap": "אדר ב׳",
	"field-hour-short": "שעה",
	"field-month-narrow": "חו׳",
	"field-hour-narrow": "שע׳",
	"field-fri-narrow-relative+-1": "יום ו׳ שעבר",
	"field-year-relative+0": "השנה",
	"field-year-relative+1": "השנה הבאה",
	"field-fri-relative+-1": "יום שישי שעבר",
	"eraNarrow": [
		"לבה״ע"
	],
	"field-tue-short-relative+-1": "יום ג׳ שעבר",
	"field-minute-narrow": "דק׳",
	"days-format-wide": [
		"יום ראשון",
		"יום שני",
		"יום שלישי",
		"יום רביעי",
		"יום חמישי",
		"יום שישי",
		"יום שבת"
	],
	"field-mon-narrow-relative+0": "יום ב׳",
	"field-mon-narrow-relative+1": "יום ב׳ הבא",
	"field-zone": "אזור",
	"dateFormatItem-MMMEd": "E, d בMMMM",
	"months-standAlone-wide-leap": "אדר ב׳",
	"field-quarter-narrow": "רבע׳",
	"field-sun-short-relative+-1": "יום א׳ שעבר",
	"field-day-relative+-1": "אתמול",
	"field-day-relative+-2": "שלשום",
	"days-format-abbr": [
		"יום א׳",
		"יום ב׳",
		"יום ג׳",
		"יום ד׳",
		"יום ה׳",
		"יום ו׳",
		"שבת"
	],
	"field-sun-relative+0": "ביום ראשון הזה",
	"field-sun-relative+1": "ביום ראשון הבא",
	"dateFormatItem-Gy": "y G",
	"field-day-short": "יום",
	"field-week-narrow": "שב׳",
	"field-era": "תקופה",
	"field-fri-narrow-relative+0": "יום ו׳",
	"field-fri-narrow-relative+1": "יום ו׳ הבא"
}
//end v1.x content
);

==> dojo_1.17.3+dfsg1.orig.tar.xz: dojo-release-1.17.3-src/dojo/cldr/nls/he/hebrew.js <==
define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "רבעון זה",
	"field-quarter-short-relative+1": "הרבעון הבא",
	"field-tue-relative+-1": "יום שלישי שעבר",
	"field-year": "שנה",
	"dateFormatItem-Hm": "H:mm",
	"field-wed-relative+0": "יום רביעי",
	"field-wed-relative+1": "יום רביעי הבא",
	"timeFormat-short": "H:mm",
	"field-minute": "דקה",
	"field-month-narrow-relative+-1": "החודש שעבר",
	"field-tue-narrow-relative+0": "יום ג׳",
	"field-tue-narrow-relative+1": "יום ג׳ הבא",
	"field-thu-short-relative+0": "יום ה׳",
	"field-day-short-relative+-1": "אתמול",
	"dateTimeFormat-short": "{1}, {0}",
	"field-thu-short-relative+1": "יום ה׳ הבא",
	"field-day-relative+0": "היום",
	"field-day-short-relative+-2": "שלשום",
	"field-day-relative+1": "מחר",
	"field-week-narrow-relative+0": "השבוע",
	"field-day-relative+2": "מחרתיים",
	"field-week-narrow-relative+1": "השבוע הבא",
	"field-wed-narrow-relative+-1": "יום ד׳ שעבר",
	"field-year-narrow": "שנ׳",
	"field-era-short": "תקופה",
	"field-year-narrow-relative+0": "השנה",
	"field-tue-relative+0": "יום שלישי",
	"field-year-narrow-relative+1": "השנה הבאה",
	"field-tue-relative+1": "יום שלישי הבא",
	"field-weekdayOfMonth": "יום חול בחודש",
	"field-second-short": "שנ׳",
	"dayPeriods-format-narrow-am": "לפנה״צ",
	"dateFormatItem-MMMd": "d בMMMM",
	"field-weekdayOfMonth-narrow": "יום בחודש",
	"dayPeriods-format-abbr-am": "לפנה״צ",
	"field-week-relative+0": "השבוע",
	"field-month-relative+0": "החודש",
	"field-week-relative+1": "השבוע הבא",
	"field-month-relative+1": "החודש הבא",
	"field-sun-narrow-relative+0": "יום א׳",
	"timeFormat-medium": "H:mm:ss",
	"field-mon-short-relative+0": "יום ב׳",
	"field-sun-narrow-relative+1": "יום א׳ הבא",
	"field-mon-short-relative+1": "יום ב׳ הבא",
	"field-second-relative+0": "עכשיו",
	"months-standAlone-narrow": [
		"תש׳",
		"חש׳",
		"כס׳",
		"טב׳",
		"שב׳",
		"א״א",
		"אד׳",
		"ני׳",
		"אי׳",
		"סי׳",
		"תמ׳",
		"אב",
		"אל׳"
	],
	"eraNames": [
		"לבריאת העולם"
	],
	"field-weekOfMonth": "השבוע בחודש",
	"field-month-short": "חו׳",
	"dateFormatItem-GyMMMEd": "E, d בMMMM y G",
	"dateFormatItem-yyyyMd": "d בMMMM y",
	"field-day": "יום",
	"field-dayOfYear-short": "יום בשנה",
	"field-year-relative+-1": "השנה שעברה",
	"dayPeriods-format-wide-am": "לפנה״צ",
	"field-sat-short-relative+-1": "שבת שעברה",
	"field-hour-relative+0": "בשעה זו",
	"dateFormatItem-yyyyMEd": "E, d בMMMM y",
	"field-wed-relative+-1": "יום רביעי שעבר",
	"dateTimeFormat-medium": "{1}, {0}",
	"field-sat-narrow-relative+-1": "שבת שעברה",
	"field-second": "שנייה",
	"days-standAlone-narrow": [
		"א׳",
		"ב׳",
		"ג׳",
		"ד׳",
		"ה׳",
		"ו׳",
		"ש׳"
	],
	"dateFormat-long": "d בMMMM y",
	"dateFormatItem-GyMMMd": "d בMMMM y G",
	"field-quarter": "רבעון",
	"field-week-short": "שב׳",
	"field-day-narrow-relative+0": "היום",
	"field-day-narrow-relative+1": "מחר",
	"quarters-standAlone-wide": [
		"רבעון 1",
		"רבעון 2",
		"רבעון 3",
		"רבעון 4"
	],
	"days-format-narrow": [
		"א׳",
		"ב׳",
		"ג׳",
		"ד׳",
		"ה׳",
		"ו׳",
		"ש׳"
	],
	"field-tue-short-relative+0": "יום ג׳",
	"field-tue-short-relative+1": "יום ג׳ הבא",
	"field-month-short-relative+-1": "החודש שעבר",
	"field-mon-relative+-1": "יום שני שעבר",
	"dateFormatItem-GyMMM": "MMMM y G",
	"field-month": "חודש",
	"field-day-narrow": "יום",
	"dateFormatItem-MMM": "MMMM",
	"field-minute-short": "דק׳",
	"field-dayperiod": "לפנה״צ/אחה״צ",
	"field-sat-short-relative+0": "שבת",
	"field-sat-short-relative+1": "שבת הבאה",
	"dayPeriods-format-narrow-pm": "אחה״צ",
	"dateFormat-medium": "d בMMMM y",
	"dateFormatItem-yyyyMMMM": "MMMM y",
	"eraAbbr": [
		"AM"
	],
	"dayPeriods-format-abbr-pm": "אחה״צ",
	"dateFormatItem-yyyyM": "MMMM y",
	"field-second-narrow": "שנ׳",
	"field-mon-relative+0": "יום שני",
	"field-mon-relative+1": "יום שני הבא",
	"field-day-narrow-relative+-1": "אתמול",
	"field-year-short": "שנ׳",
	"field-day-narrow-relative+-2": "שלשום",
	"months-format-narrow": [
		"תש׳",
		"חש׳",
		"כס׳",
		"טב׳",
		"שב׳",
		"א״א",
		"אד׳",
		"ני׳",
		"אי׳",
		"סי׳",
		"תמ׳",
		"אב",
		"אל׳"
	],
	"field-quarter-relative+-1": "הרבעון הקודם",
	"dateFormatItem-yyyyMMMd": "d בMMMM y",
	"field-dayperiod-narrow": "AM/PM",
	"dayPeriods-standAlone-narrow-am": "לפנה״צ",
	"field-week-narrow-relative+-1": "השבוע שעבר",
	"days-format-short": [
		"א׳",
		"ב׳",
		"ג׳",
		"ד׳",
		"ה׳",
		"ו׳",
		"ש׳"
	],
	"dayPeriods-format-wide-pm": "אחה״צ",
	"field-dayOfYear": "יום בשנה",
	"field-sat-relative+-1": "יום שבת שעבר",
	"dateTimeFormat-long": "{1} בשעה {0}",
	"dateFormatItem-Md": "d בMMMM",
	"field-hour": "שעה",
	"months-format-wide": [
		"תשרי",
		"חשוון",
		"כסלו",
		"טבת",
		"שבט",
		"אדר א׳",
		"אדר",
		"ניסן",
		"אייר",
		"סיוון",
		"תמוז",
		"אב",
		"אלול"
	],
	"dateFormat-full": "EEEE, d בMMMM y",
	"field-month-relative+-1": "החודש שעבר",
	"dateFormatItem-Hms": "H:mm:ss",
	"field-quarter-short": "רבע׳",
	"field-sat-narrow-relative+0": "שבת",
	"field-fri-relative+0": "יום שישי",
	"field-sat-narrow-relative+1": "שבת הבאה",
	"field-fri-relative+1": "יום שישי הבא",
	"field-month-narrow-relative+0": "החודש",
	"field-month-narrow-relative+1": "החודש הבא",
	"field-sun-short-relative+0": "יום א׳",
	"field-sun-short-relative+1": "יום א׳ הבא",
	"field-week-relative+-1": "השבוע שעבר",
	"field-quarter-short-relative+-1": "הרבעון הקודם",
	"months-format-abbr": [
		"תשרי",
		"חשון",
		"כסלו",
		"טבת",
		"שבט",
		"אדר א׳",
		"אדר",
		"ניסן",
		"אייר",
		"סיון",
		"תמוז",
		"אב",
		"אלול"
	],
	"field-quarter-relative+0": "רבעון זה",
	"field-minute-relative+0": "בדקה זו",
	"timeFormat-long": "H:mm:ss z",
	"field-quarter-relative+1": "הרבעון הבא",
	"field-wed-short-relative+-1": "יום ד׳ שעבר",
	"dateFormat-short": "d בMMMM y",
	"field-thu-short-relative+-1": "יום ה׳ שעבר",
	"field-year-narrow-relative+-1": "השנה שעברה",
	"days-standAlone-wide": [
		"יום ראשון",
		"יום שני",
		"יום שלישי",
		"יום רביעי",
		"יום חמישי",
		"יום שישי",
		"יום שבת"
	],
	"dateFormatItem-yyyyMMMEd": "E, d בMMMM y",
	"field-mon-narrow-relative+-1": "יום ב׳ שעבר",
	"dateFormatItem-MMMMd": "d בMMMM",
	"field-thu-narrow-relative+-1": "יום ה׳ שעבר",
	"field-tue-narrow-relative+-1": "יום ג׳ שעבר",
	"dateFormatItem-H": "H",
	"field-weekOfMonth-short": "השבוע בחודש",
	"dateFormatItem-yyyy": "y G",
	"dayPeriods-standAlone-narrow-pm": "אחה״צ",
	"dateFormatItem-M": "MMMM",
	"months-standAlone-wide": [
		"תשרי",
		"חשוון",
		"כסלו",
		"טבת",
		"שבט",
		"אדר א׳",
		"אדר",
		"ניסן",
		"אייר",
		"סיוון",
		"תמוז",
		"אב",
		"אלול"
	],
	"field-wed-short-relative+0": "יום ד׳",
	"field-wed-short-relative+1": "יום ד׳ הבא",
	"field-sun-relative+-1": "ביום ראשון שעבר",
	"dateFormatItem-MMMMEd": "E, d בMMMM",
	"days-standAlone-abbr": [
		"יום א׳",
		"יום ב׳",
		"יום ג׳",
		"יום ד׳",
		"יום ה׳",
		"יום ו׳",
		"שבת"
	],
	"dateTimeFormat-full": "{1} בשעה {0}",
	"months-format-abbr-leap": "אדר ב׳",
	"field-weekday": "יום בשבוע",
	"months-standAlone-narrow-leap": "א״ב",
	"field-day-short-relative+0": "היום",
	"field-quarter-narrow-relative+0": "רבעון זה",
	"field-day-short-relative+1": "מחר",
	"field-sat-relative+0": "יום שבת",
	"field-quarter-narrow-relative+1": "הרבעון הבא",
	"field-day-short-relative+2": "מחרתיים",
	"field-sat-relative+1": "יום שבת הבא",
	"field-week-short-relative+0": "השבוע",
	"field-week-short-relative+1": "השבוע הבא",
	"months-standAlone-abbr": [
		"תשרי",
		"חשון",
		"כסלו",
		"טבת",
		"שבט",
		"אדר א׳",
		"אדר",
		"ניסן",
		"אייר",
		"סיון",
		"תמוז",
		"אב",
		"אלול"
	],
	"months-format-wide-leap": "אדר ב׳",
	"months-format-narrow-leap": "א״ב",
	"field-dayOfYear-narrow": "יום בשנה",
	"field-month-short-relative+0": "החודש",
	"field-month-short-relative+1": "החודש הבא",
	"field-weekdayOfMonth-short": "יום בחודש",
	"timeFormat-full": "H:mm:ss zzzz",
	"dateFormatItem-MEd": "E, d בMMMM",
	"field-zone-narrow": "אזור",
	"dateFormatItem-y": "y G",
	"field-thu-narrow-relative+0": "יום ה׳",
	"field-sun-narrow-relative+-1": "יום א׳ שעבר",
	"field-mon-short-relative+-1": "יום ב׳ שעבר",
	"field-thu-narrow-relative+1": "יום ה׳ הבא",
	"field-thu-relative+0": "יום חמישי",
	"field-thu-relative+1": "יום חמישי הבא",
	"field-fri-short-relative+-1": "יום ו׳ שעבר",
	"field-thu-relative+-1": "יום חמישי שעבר",
	"field-week": "שבוע",
	"quarters-format-wide": [
		"רבעון 1",
		"רבעון 2",
		"רבעון 3",
		"רבעון 4"
	],
	"dateFormatItem-Ed": "E d",
	"field-wed-narrow-relative+0": "יום ד׳",
	"field-wed-narrow-relative+1": "יום ד׳ הבא",
	"field-quarter-narrow-relative+-1": "הרבעון הקודם",
	"field-year-short-relative+0": "השנה",
	"dateFormatItem-yyyyMMM": "MMMM y",
	"field-dayperiod-short": "AM/PM",
	"field-year-short-relative+1": "השנה הבאה",
	"field-fri-short-relative+0": "יום ו׳",
	"field-fri-short-relative+1": "יום ו׳ הבא",
	"days-standAlone-short": [
		"א׳",
		"ב׳",
		"ג׳",
		"ד׳",
		"ה׳",
		"ו׳",
		"ש׳"
	],
	"field-week-short-relative+-1": "השבוע שעבר",
	"months-standAlone-abbr-leap": "אדר ב׳",
	"field-hour-short": "שעה",
	"field-zone-short": "אזור",
	"field-month-narrow": "חו׳",
	"field-hour-narrow": "שע׳",
	"field-fri-narrow-relative+-1": "יום ו׳ שעבר",
	"field-year-relative+0": "השנה",
	"field-year-relative+1": "השנה הבאה",
	"field-era-narrow": "תקופה",
	"field-fri-relative+-1": "יום שישי שעבר",
	"eraNarrow": "AM",
	"field-tue-short-relative+-1": "יום ג׳ שעבר",
	"field-minute-narrow": "דק׳",
	"days-format-wide": [
		"יום ראשון",
		"יום שני",
		"יום שלישי",
		"יום רביעי",
		"יום חמישי",
		"יום שישי",
		"יום שבת"
	],
	"field-mon-narrow-relative+0": "יום ב׳",
	"field-mon-narrow-relative+1": "יום ב׳ הבא",
	"field-year-short-relative+-1": "השנה שעברה",
	"field-zone": "אזור זמן",
	"dateFormatItem-MMMEd": "E, d בMMMM",
	"field-weekOfMonth-narrow": "השבוע בחודש",
	"field-weekday-narrow": "יום בשבוע",
	"months-standAlone-wide-leap": "אדר ב׳",
	"field-quarter-narrow": "רבע׳",
	"field-sun-short-relative+-1": "יום א׳ שעבר",
	"field-day-relative+-1": "אתמול",
	"field-day-relative+-2": "שלשום",
	"field-weekday-short": "יום בשבוע",
	"days-format-abbr": [
		"יום א׳",
		"יום ב׳",
		"יום ג׳",
		"יום ד׳",
		"יום ה׳",
		"יום ו׳",
		"שבת"
	],
	"field-sun-relative+0": "ביום ראשון הזה",
	"field-sun-relative+1": "ביום ראשון הבא",
	"dateFormatItem-Gy": "y G",
	"field-day-short": "יום",
	"field-week-narrow": "שב׳",
	"field-era": "תקופה",
	"field-fri-narrow-relative+0": "יום ו׳",
	"field-fri-narrow-relative+1": "יום ו׳ הבא"
}
//end v1.x content
);
